==> python_loki_client-0.1.1-py3-none-any.whl: grafana_loki_client/models/query_response_metric.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.query_response_metric_level import QueryResponseMetricLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="QueryResponseMetric")


@attr.s(auto_attribs=True)
class QueryResponseMetric:
    """
    Attributes:
        level (Union[Unset, QueryResponseMetricLevel]):
    """

    level: Union[Unset, QueryResponseMetricLevel] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        level: Union[Unset, str] = UNSET
        if not isinstance(self.level, Unset):
            level = self.level.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if level is not UNSET:
            field_dict["level"] = level

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _level = d.pop("level", UNSET)
        level: Union[Unset, QueryResponseMetricLevel]
        if isinstance(_level, Unset):
            level = UNSET
        else:
            level = QueryResponseMetricLevel(_level)

        query_response_metric = cls(
            level=level,
        )

        query_response_metric.additional_properties = d
        return query_response_metric

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> python_loki_clientv2-0.1.3-py3-none-any.whl: grafana_loki_client/models/query_response_metric.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.query_response_metric_level import QueryResponseMetricLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="QueryResponseMetric")


@_attrs_define
class QueryResponseMetric:
    """
    Attributes:
        level (Union[Unset, QueryResponseMetricLevel]):
    """

    level: Union[Unset, QueryResponseMetricLevel] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        level: Union[Unset, str] = UNSET
        if not isinstance(self.level, Unset):
            level = self.level.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if level is not UNSET:
            field_dict["level"] = level

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _level = d.pop("level", UNSET)
        level: Union[Unset, QueryResponseMetricLevel]
        if isinstance(_level, Unset):
            level = UNSET
        else:
            level = QueryResponseMetricLevel(_level)

        query_response_metric = cls(
            level=level,
        )

        query_response_metric.additional_properties = d
        return query_response_metric

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
